@@ -1,6 +1,6 @@
 /*=========================================================================
  *
- *  Copyright Insight Software Consortium
+ *  Copyright NumFOCUS
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -29,7 +29,7 @@ namespace itk
 {
 
 /** \class DisplacementFieldTransform
- * \brief Provides local/dense/high-dimensionaltiy transformation via a
+ * \brief Provides local/dense/high-dimensionality transformation via a
  * a displacement field.
  *
  * The displacement field stores vectors of displacements, with
@@ -82,10 +82,8 @@ namespace itk
  *
  * \ingroup ITKDisplacementField
  */
-template
-<typename TParametersValueType, unsigned int NDimensions>
-class ITK_TEMPLATE_EXPORT DisplacementFieldTransform :
-  public Transform<TParametersValueType, NDimensions, NDimensions>
+template <typename TParametersValueType, unsigned int NDimensions>
+class ITK_TEMPLATE_EXPORT DisplacementFieldTransform : public Transform<TParametersValueType, NDimensions, NDimensions>
 {
 public:
   ITK_DISALLOW_COPY_AND_ASSIGN(DisplacementFieldTransform);
@@ -97,10 +95,10 @@ public:
   using ConstPointer = SmartPointer<const Self>;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro( DisplacementFieldTransform, Transform );
+  itkTypeMacro(DisplacementFieldTransform, Transform);
 
   /** New macro for creation of through a Smart Pointer */
-  itkNewMacro( Self );
+  itkNewMacro(Self);
 
   /** InverseTransform type. */
   using InverseTransformBasePointer = typename Superclass::InverseTransformBasePointer;
@@ -120,9 +118,9 @@ public:
   using InverseJacobianPositionType = typename Superclass::InverseJacobianPositionType;
 
   /** Transform category type. */
-  using TransformCategoryType = typename Superclass::TransformCategoryType;
+  using TransformCategoryEnum = typename Superclass::TransformCategoryEnum;
 
-  /** The number of parameters defininig this transform. */
+  /** The number of parameters defining this transform. */
   using NumberOfParametersType = typename Superclass::NumberOfParametersType;
 
   /** Standard coordinate point type for this class. */
@@ -149,10 +147,8 @@ public:
   using OutputDiffusionTensor3DType = typename Superclass::OutputDiffusionTensor3DType;
 
   /** Standard tensor type for this class */
-  using InputTensorEigenVectorType =
-      CovariantVector<ScalarType, InputDiffusionTensor3DType::Dimension>;
-  using OutputTensorEigenVectorType =
-      CovariantVector<ScalarType, OutputDiffusionTensor3DType::Dimension>;
+  using InputTensorEigenVectorType = CovariantVector<ScalarType, InputDiffusionTensor3DType::Dimension>;
+  using OutputTensorEigenVectorType = CovariantVector<ScalarType, OutputDiffusionTensor3DType::Dimension>;
   /** Derivative type */
   using DerivativeType = typename Superclass::DerivativeType;
 
@@ -160,12 +156,11 @@ public:
   static constexpr unsigned int Dimension = NDimensions;
 
   /** Define the displacement field type and corresponding interpolator type. */
-  using DisplacementFieldType = Image<OutputVectorType,  Dimension>;
+  using DisplacementFieldType = Image<OutputVectorType, Dimension>;
   using DisplacementFieldPointer = typename DisplacementFieldType::Pointer;
   using DisplacementFieldConstPointer = typename DisplacementFieldType::ConstPointer;
 
-  using InterpolatorType = VectorInterpolateImageFunction
-    <DisplacementFieldType, ScalarType>;
+  using InterpolatorType = VectorInterpolateImageFunction<DisplacementFieldType, ScalarType>;
 
   /** Standard types for the displacement Field */
   using IndexType = typename DisplacementFieldType::IndexType;
@@ -177,108 +172,114 @@ public:
   using PixelType = typename DisplacementFieldType::PixelType;
 
   /** Define the internal parameter helper used to access the field */
-  using OptimizerParametersHelperType = ImageVectorOptimizerParametersHelper<
-    ScalarType,
-    OutputVectorType::Dimension,
-    Dimension>;
+  using OptimizerParametersHelperType =
+    ImageVectorOptimizerParametersHelper<ScalarType, OutputVectorType::Dimension, Dimension>;
 
   /** Get/Set the displacement field.
    * Set the displacement field. Create special set accessor to update
    * interpolator and assign displacement field to transform parameters
    * container. */
-  virtual void SetDisplacementField( DisplacementFieldType* field );
-  itkGetModifiableObjectMacro(DisplacementField, DisplacementFieldType );
+  virtual void
+  SetDisplacementField(DisplacementFieldType * field);
+  itkGetModifiableObjectMacro(DisplacementField, DisplacementFieldType);
 
   /** Get/Set the inverse displacement field. This must be supplied by the user for
    * GetInverse() to work. */
-  virtual void SetInverseDisplacementField( DisplacementFieldType * inverseDisplacementField );
-  itkGetModifiableObjectMacro(InverseDisplacementField, DisplacementFieldType );
+  virtual void
+  SetInverseDisplacementField(DisplacementFieldType * inverseDisplacementField);
+  itkGetModifiableObjectMacro(InverseDisplacementField, DisplacementFieldType);
 
   /** Get/Set the interpolator.
    * Create out own set accessor that assigns the displacement field. */
-  virtual void SetInterpolator( InterpolatorType* interpolator );
-  itkGetModifiableObjectMacro( Interpolator, InterpolatorType );
+  virtual void
+  SetInterpolator(InterpolatorType * interpolator);
+  itkGetModifiableObjectMacro(Interpolator, InterpolatorType);
 
   /** Get/Set the interpolator for the inverse field.
    * Create out own set accessor that assigns the displacement field. */
-  virtual void SetInverseInterpolator( InterpolatorType* interpolator );
-  itkGetModifiableObjectMacro(InverseInterpolator, InterpolatorType );
+  virtual void
+  SetInverseInterpolator(InterpolatorType * interpolator);
+  itkGetModifiableObjectMacro(InverseInterpolator, InterpolatorType);
 
   /** Get the modification time of displacement field. */
-  itkGetConstReferenceMacro( DisplacementFieldSetTime, ModifiedTimeType );
+  itkGetConstReferenceMacro(DisplacementFieldSetTime, ModifiedTimeType);
 
   /**  Method to transform a point. Out-of-bounds points will
-   * be returned with zero displacemnt. */
-  OutputPointType TransformPoint( const InputPointType& thisPoint ) const override;
+   * be returned with zero displacement. */
+  OutputPointType
+  TransformPoint(const InputPointType & thisPoint) const override;
 
   /**  Method to transform a vector. */
   using Superclass::TransformVector;
-  OutputVectorType TransformVector(const InputVectorType &) const override
+  OutputVectorType
+  TransformVector(const InputVectorType &) const override
   {
-    itkExceptionMacro( "TransformVector(Vector) unimplemented, use "
-                       "TransformVector(Vector,Point)" );
+    itkExceptionMacro("TransformVector(Vector) unimplemented, use "
+                      "TransformVector(Vector,Point)");
   }
 
-  OutputVectorPixelType TransformVector(const InputVectorPixelType &) const override
+  OutputVectorPixelType
+  TransformVector(const InputVectorPixelType &) const override
   {
-    itkExceptionMacro( "TransformVector(Vector) unimplemented, use "
-                       "TransformVector(Vector,Point)" );
+    itkExceptionMacro("TransformVector(Vector) unimplemented, use "
+                      "TransformVector(Vector,Point)");
   }
 
-  OutputVnlVectorType TransformVector(const InputVnlVectorType &) const override
+  OutputVnlVectorType
+  TransformVector(const InputVnlVectorType &) const override
   {
-    itkExceptionMacro( "TransformVector(Vector) unimplemented, use "
-                       "TransformVector(Vector,Point)" );
+    itkExceptionMacro("TransformVector(Vector) unimplemented, use "
+                      "TransformVector(Vector,Point)");
   }
 
   /** Method to transform a tensor. */
   using Superclass::TransformDiffusionTensor3D;
-  OutputDiffusionTensor3DType TransformDiffusionTensor(
-    const InputDiffusionTensor3DType & ) const
+  OutputDiffusionTensor3DType
+  TransformDiffusionTensor(const InputDiffusionTensor3DType &) const
   {
-    itkExceptionMacro( "TransformDiffusionTensor(Tensor) unimplemented, use "
-                       "TransformDiffusionTensor(Tensor,Point)" );
+    itkExceptionMacro("TransformDiffusionTensor(Tensor) unimplemented, use "
+                      "TransformDiffusionTensor(Tensor,Point)");
   }
 
-  OutputVectorPixelType TransformDiffusionTensor(const InputVectorPixelType & )
-  const
+  OutputVectorPixelType
+  TransformDiffusionTensor(const InputVectorPixelType &) const
   {
-    itkExceptionMacro( "TransformDiffusionTensor(Tensor) unimplemented, use "
-                       "TransformDiffusionTensor(Tensor,Point)" );
+    itkExceptionMacro("TransformDiffusionTensor(Tensor) unimplemented, use "
+                      "TransformDiffusionTensor(Tensor,Point)");
   }
 
   /** Method to transform a CovariantVector. */
   using Superclass::TransformCovariantVector;
-  OutputCovariantVectorType TransformCovariantVector(
-    const InputCovariantVectorType &) const override
+  OutputCovariantVectorType
+  TransformCovariantVector(const InputCovariantVectorType &) const override
   {
-    itkExceptionMacro( "TransformCovariantVector(CovariantVector) "
-                       "unimplemented, use TransformCovariantVector(CovariantVector,Point)" );
+    itkExceptionMacro("TransformCovariantVector(CovariantVector) "
+                      "unimplemented, use TransformCovariantVector(CovariantVector,Point)");
   }
 
-  OutputVectorPixelType TransformCovariantVector(
-    const InputVectorPixelType &) const override
+  OutputVectorPixelType
+  TransformCovariantVector(const InputVectorPixelType &) const override
   {
-    itkExceptionMacro( "TransformCovariantVector(CovariantVector) "
-                       "unimplemented, use TransformCovariantVector(CovariantVector,Point)" );
+    itkExceptionMacro("TransformCovariantVector(CovariantVector) "
+                      "unimplemented, use TransformCovariantVector(CovariantVector,Point)");
   }
 
   /** Set the transformation parameters. This sets the displacement
    * field image directly. */
-  void SetParameters(const ParametersType & params) override
+  void
+  SetParameters(const ParametersType & params) override
   {
-    if( &(this->m_Parameters) != &params )
+    if (&(this->m_Parameters) != &params)
+    {
+      if (params.Size() != this->m_Parameters.Size())
       {
-      if( params.Size() != this->m_Parameters.Size() )
-        {
-        itkExceptionMacro("Input parameters size (" << params.Size()
-                                                    << ") does not match internal size ("
+        itkExceptionMacro("Input parameters size (" << params.Size() << ") does not match internal size ("
                                                     << this->m_Parameters.Size() << ").");
-        }
+      }
       // Copy into existing object
       this->m_Parameters = params;
       this->Modified();
-      }
+    }
   }
 
   /**
@@ -290,7 +291,8 @@ public:
    * creates a new one with zero displacement (identity transform). If
    * an inverse displacement field exists, a new one is also created.
    */
-  void SetFixedParameters( const FixedParametersType & ) override;
+  void
+  SetFixedParameters(const FixedParametersType &) override;
 
   /**
    * Compute the jacobian with respect to the parameters at a point.
@@ -313,8 +315,8 @@ public:
    *
    * TODO: format the above for doxygen formula.
    */
-  void ComputeJacobianWithRespectToParameters(const InputPointType &,
-                                                      JacobianType & j) const override
+  void
+  ComputeJacobianWithRespectToParameters(const InputPointType &, JacobianType & j) const override
   {
     j = this->m_IdentityJacobian;
   }
@@ -325,8 +327,8 @@ public:
    * See \c ComputeJacobianWithRespectToParameters( InputPointType, ... )
    * for rationale.
    */
-  virtual void ComputeJacobianWithRespectToParameters(const IndexType &,
-                                                      JacobianType & j) const
+  virtual void
+  ComputeJacobianWithRespectToParameters(const IndexType &, JacobianType & j) const
   {
     j = this->m_IdentityJacobian;
   }
@@ -335,22 +337,24 @@ public:
    * Compute the jacobian with respect to the position, by point.
    * \c j will be resized as needed.
    */
-  void ComputeJacobianWithRespectToPosition(const InputPointType  & x, JacobianPositionType & j ) const override;
+  void
+  ComputeJacobianWithRespectToPosition(const InputPointType & x, JacobianPositionType & j) const override;
   using Superclass::ComputeJacobianWithRespectToPosition;
 
   /**
    * Compute the jacobian with respect to the position, by point.
    * \c j will be resized as needed.
    */
-  void ComputeInverseJacobianWithRespectToPosition(const InputPointType  & x,
-                                                   InverseJacobianPositionType & j ) const override;
+  void
+  ComputeInverseJacobianWithRespectToPosition(const InputPointType & x, InverseJacobianPositionType & j) const override;
   using Superclass::ComputeInverseJacobianWithRespectToPosition;
 
   /**
    * Compute the jacobian with respect to the position, by index.
    * \c j will be resized as needed.
    */
-  virtual void ComputeJacobianWithRespectToPosition(const IndexType  & x, JacobianPositionType & j ) const;
+  virtual void
+  ComputeJacobianWithRespectToPosition(const IndexType & x, JacobianPositionType & j) const;
 
   /**
    * Compute the inverse jacobian of the forward displacement field with
@@ -363,9 +367,10 @@ public:
    * method is more computationally expensive and may be used by
    * setting \c useSVD to true
    */
-  virtual void GetInverseJacobianOfForwardFieldWithRespectToPosition(const InputPointType & point,
-                                                                     JacobianPositionType & jacobian,
-                                                                     bool useSVD = false ) const;
+  virtual void
+  GetInverseJacobianOfForwardFieldWithRespectToPosition(const InputPointType & point,
+                                                        JacobianPositionType & jacobian,
+                                                        bool                   useSVD = false) const;
 
   /**
    * Compute the inverse jacobian of the forward displacement field with
@@ -378,29 +383,36 @@ public:
    * method is more computationally expensive and may be used by
    * setting \c useSVD to true
    */
-  virtual void GetInverseJacobianOfForwardFieldWithRespectToPosition(const IndexType & index,
-                                                                     JacobianPositionType & jacobian,
-                                                                     bool useSVD = false ) const;
+  virtual void
+  GetInverseJacobianOfForwardFieldWithRespectToPosition(const IndexType &      index,
+                                                        JacobianPositionType & jacobian,
+                                                        bool                   useSVD = false) const;
 
-  void UpdateTransformParameters( const DerivativeType & update, ScalarType factor = 1.0 ) override;
+  void
+  UpdateTransformParameters(const DerivativeType & update, ScalarType factor = 1.0) override;
 
   /** Return an inverse of this transform.
    * Note that the inverse displacement field must be set by the user. */
-  bool GetInverse( Self *inverse ) const;
+  bool
+  GetInverse(Self * inverse) const;
 
   /** Return an inverse of this transform.
    * Note that the inverse displacement field must be set by the user. */
-  InverseTransformBasePointer GetInverseTransform() const override;
+  InverseTransformBasePointer
+  GetInverseTransform() const override;
 
-  virtual void SetIdentity();
+  virtual void
+  SetIdentity();
 
   /** This transform is not linear. */
-  TransformCategoryType GetTransformCategory() const override
+  TransformCategoryEnum
+  GetTransformCategory() const override
   {
-    return Self::DisplacementField;
+    return Self::TransformCategoryEnum::DisplacementField;
   }
 
-  NumberOfParametersType GetNumberOfLocalParameters() const override
+  NumberOfParametersType
+  GetNumberOfLocalParameters() const override
   {
     return Dimension;
   }
@@ -426,18 +438,18 @@ public:
   itkGetConstMacro(DirectionTolerance, double);
 
 protected:
-
   DisplacementFieldTransform();
   ~DisplacementFieldTransform() override = default;
-  void PrintSelf( std::ostream& os, Indent indent ) const override;
+  void
+  PrintSelf(std::ostream & os, Indent indent) const override;
 
   /** The displacement field and its inverse (if it exists). */
-  typename DisplacementFieldType::Pointer      m_DisplacementField;
-  typename DisplacementFieldType::Pointer      m_InverseDisplacementField;
+  typename DisplacementFieldType::Pointer m_DisplacementField;
+  typename DisplacementFieldType::Pointer m_InverseDisplacementField;
 
   /** The interpolator. */
-  typename InterpolatorType::Pointer          m_Interpolator;
-  typename InterpolatorType::Pointer          m_InverseInterpolator;
+  typename InterpolatorType::Pointer m_Interpolator;
+  typename InterpolatorType::Pointer m_InverseInterpolator;
 
   /** Track when the displacement field was last set/assigned, as
    * distinct from when it may have had its contents modified. */
@@ -456,31 +468,33 @@ private:
    * \c doInverseJacobian indicates that the inverse jacobian
    * should be returned
    */
-  virtual void ComputeJacobianWithRespectToPositionInternal(const IndexType & index,
-                                                            JacobianPositionType & jacobian,
-                                                            bool doInverseJacobian) const;
+  virtual void
+  ComputeJacobianWithRespectToPositionInternal(const IndexType &      index,
+                                               JacobianPositionType & jacobian,
+                                               bool                   doInverseJacobian) const;
 
   /**
    * Internal method to check that the inverse and forward displacement fields have the
    * same fixed parameters.
    */
-  virtual void VerifyFixedParametersInformation();
+  virtual void
+  VerifyFixedParametersInformation();
 
   /**
    * Convenience method which reads the information from the current
    * displacement field into m_FixedParameters.
    */
-  virtual void SetFixedParametersFromDisplacementField() const;
+  virtual void
+  SetFixedParametersFromDisplacementField() const;
 
   double m_CoordinateTolerance;
   double m_DirectionTolerance;
-
 };
 
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
-#include "itkDisplacementFieldTransform.hxx"
+#  include "itkDisplacementFieldTransform.hxx"
 #endif
 
 #endif // itkDisplacementFieldTransform_h
